# Prompt

Helper for your tty interactions

Version: 0.0.21

## Requirements

- Python >=3.6

## Dependencies

- colorama
- inquirerpy
- pip-tools
- pydantic
- pytest

## Installation

```bash
pip install wexample-prompt
```

## Links

- Homepage: https://github.com/wexample/python-prompt

## License

MIT
## Credits

This package has been developed by [Wexample](https://wexample.com), a collection of tools and utilities to streamline development workflows.

Visit [wexample.com](https://wexample.com) to discover more tools and resources for efficient development.